@@ -1,4 +1,5 @@
 import logging
+import os
 import shutil
 import sys
 from subprocess import PIPE, CalledProcessError, run as subprocess_run  # nosec
@@ -53,7 +54,8 @@ class TypescriptLanguagePlugin(LanguagePlugin):
         self.namespace = None
         self.package_name = None
         self.package_root = None
-        self._use_docker = True
+        self._use_docker = None
+        self._no_docker = None
         self._protocol_version = "2.0.0"
         self._build_command = None
         self._lib_path = None
@@ -61,20 +63,40 @@ class TypescriptLanguagePlugin(LanguagePlugin):
     def _init_from_project(self, project):
         self.namespace = tuple(s.lower() for s in project.type_info)
         self.package_name = "-".join(self.namespace)
-        self._use_docker = project.settings.get("useDocker", True)
+        # Check config file for (legacy) 'useDocker' and use_docker settings
+        self._use_docker = project.settings.get("useDocker") or project.settings.get(
+            "use_docker"
+        )
         self.package_root = project.root / "src"
         self._build_command = project.settings.get("buildCommand", None)
         self._lib_path = SUPPORT_LIB_VERSION
 
     def _init_settings(self, project):
         LOG.debug("Writing settings")
-        self._use_docker = input_with_validation(
-            "Use docker for platform-independent packaging (Y/n)?\n",
-            validate_no,
-            "This is highly recommended unless you are experienced \n"
-            "with cross-platform Typescript packaging.",
-        )
-        project.settings["useDocker"] = self._use_docker
+        # If use_docker specified in .rpdk-config file or cli switch
+        # Ensure only 1 is true, with preference to use_docker
+        if project.settings.get("use_docker") is True:
+            self._use_docker = True
+            self._no_docker = False
+        # If no_docker specified in .rpdk-config file or cli switch
+        elif project.settings.get("no_docker") is True:
+            self._use_docker = False
+            self._no_docker = True
+        else:
+            # If neither no_docker nor use_docker specified in .rpdk-config
+            # file or cli switch, prompt to use containers or not
+            self._use_docker = input_with_validation(
+                "Use docker for platform-independent packaging (Y/n)?\n",
+                validate_no,
+                "This is highly recommended unless you are experienced \n"
+                "with cross-platform Typescript packaging.",
+            )
+            self._no_docker = not self._use_docker
+
+        # switched to 'use_docker' from 'useDocker' to be in line with python version
+        # project.settings will get saved into .rpdk-config by cloudformation-cli
+        project.settings["use_docker"] = self._use_docker
+        project.settings["no_docker"] = self._no_docker
         project.settings["protocolVersion"] = self._protocol_version
 
     def init(self, project):
@@ -230,8 +252,8 @@ class TypescriptLanguagePlugin(LanguagePlugin):
     @staticmethod
     def _make_build_command(base_path, build_command=None):
         command = (
-            "npm install --optional "
-            + f"&& sam build --debug --build-dir {base_path}/build"
+            "npm install --include=optional "
+            + f"&& sam build --debug --build-dir {os.path.join(base_path, 'build')}"
         )
         if build_command is not None:
             command = build_command
@@ -251,13 +273,32 @@ class TypescriptLanguagePlugin(LanguagePlugin):
 
         LOG.warning("Starting build.")
         try:
-            completed_proc = subprocess_run(  # nosec
-                ["/bin/bash", "-c", command],
-                stdout=PIPE,
-                stderr=PIPE,
-                cwd=base_path,
-                check=True,
-            )
+            # On windows get the default CLI in environment variable comspec
+            # run 1 command and exit. Building shell command manually, subprocess.run
+            # with shell=True behavior is inconsistent on windows
+            if sys.platform == "win32":  # pragma: no cover
+                shell = os.environ.get("comspec")
+                shell_arg = "/C"
+                completed_proc = subprocess_run(  # nosec
+                    [shell, shell_arg, command],
+                    stdout=PIPE,
+                    stderr=PIPE,
+                    cwd=base_path,
+                    check=True,
+                    universal_newlines=True,
+                )
+            else:  # pragma: no cover
+                # On all other OS use default shell in subprocess to run build command
+                completed_proc = subprocess_run(  # nosec
+                    [command],
+                    stdout=PIPE,
+                    stderr=PIPE,
+                    cwd=base_path,
+                    check=True,
+                    shell=True,
+                    universal_newlines=True,
+                )
+
         except (FileNotFoundError, CalledProcessError) as e:
             raise DownstreamError("local build failed") from e
 
